@@ -27,7 +27,7 @@ use Exporter;
 require DynaLoader;
 our @ISA = qw(DynaLoader Exporter);
 
-our $VERSION = '1.313';
+our $VERSION = '1.314';
 
 use constant {
 	TRUE  => 1,
@@ -100,6 +100,12 @@ sub domain { $_[0]->{domain} }
 sub value { $_[0]->{value} }
 sub code { $_[0]->{code} }
 
+package Glib::Bytes;
+
+use overload
+   '""' => sub { $_[0]->get_data },
+   fallback => 1;
+
 package Glib::Object::Property;
 
 use Carp;
